/* Code : adxl346 et diodes 3 couleurs 
 * pour digispark attiny85 (code validé sur arduino nano)
 * R. Suinot [remi <at> suinot.org]
 * 08 juil 2021
 * rev: 
*/

#include <Adafruit_NeoPixel.h>
#include <SparkFun_ADXL345.h>
#include <Wire.h>  // Wire library - used for I2C communication

#define PIN_LED 3     // (numéroté 2 ou PB3 sur didigispark) Control signal: DI 
#define NUM_LED 3     // Number of LEDs in a strip

int ADXL345 = 0x53; // The ADXL345 sensor I2C address (pin 5=PB0 et 7=PB2 sur le digispark)
float X_out, Y_out, Z_out;  // valeur de l'adxl345

#define DELAY 250 // à modifier si changement de couleurs trop ou pas assez rapide

// Custom colour4: White
#define RED_VAL       255
#define GREEN_VAL     255
#define BLUE_VAL      255

Adafruit_NeoPixel RGB_Strip = Adafruit_NeoPixel(NUM_LED, PIN_LED, NEO_GRB + NEO_KHZ800);


void setup() {
  // préparation de la communication en i2c
  Wire.begin(); // Initialisation de la communication i2c
  // mise de l'ADXL345 en mode mesure
  Wire.beginTransmission(ADXL345); // Début de communication 
  Wire.write(0x2D); // toc toc toc à la porte "POWER_CTL" registre 0x2D
  // lecture des mesures
  Wire.write(8); // (8 décimal -> 0000 1000 binaire) Bit D3 haut pour le mode mesure 
  Wire.endTransmission();
  delay(10);

  // préparation des led 
  RGB_Strip.begin();
  RGB_Strip.show();
  RGB_Strip.setBrightness(128);    // Set brightness, 0-255 (darkest - brightest)

}

void loop() {
  /* 
   *  le mouvement de l'adxl va modifier les couleurs des leds:
  */
  // === lecture des données de l'Adxl === //
  Wire.beginTransmission(ADXL345);
  Wire.write(0x32); // Start avec le registre 0x32 (ACCEL_XOUT_H)
  Wire.endTransmission(false);
  Wire.requestFrom(ADXL345, 6, true); // lecture de 6 registres au total
                                      // d'autre valeurs d'axes sont stockées dans 2 registres
  X_out = ( Wire.read()| Wire.read() << 8); // X-axis 
  //X_out = X_out/256; // Pour une plage de +-2g, il faut diviser les valeurs brutes par 256
  Y_out = ( Wire.read()| Wire.read() << 8); // Y-axis 
  //Y_out = Y_out/256;
  Z_out = ( Wire.read()| Wire.read() << 8); // Z-axis 
  //Z_out = Z_out/256;

  // nous avont nos valeurs d'axes, modifions les couleurs
  colorWipe(RGB_Strip.Color(RED_VAL*X_out, GREEN_VAL*Y_out, BLUE_VAL*Z_out), DELAY);   // Custom colour1: Yellow

}

// Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint16_t wait) {
    RGB_Strip.setPixelColor(0, c);
    RGB_Strip.setPixelColor(1, c);
    RGB_Strip.setPixelColor(2, c);
    RGB_Strip.show();
    delay(wait);
}
